@@ -10,19 +10,19 @@ from PIL import Image
 class PysonConnect:
     def __init__(self, client_id=None, client_secret=None):
         if client_id == None:
-            self.client_id = os.environ["epsonClientID"]
+            self.client_id = os.environ['epsonClientID']
 
         else:
             self.client_id = client_id
 
         if client_secret == None:
-            self.client_secret = os.environ["epsonClientSecret"]
+            self.client_secret = os.environ['epsonClientSecret']
 
         else:
             self.client_secret = client_secret
 
         self.err = Errors()
-        self.base_uri = "https://api.epsonconnect.com"
+        self.base_uri = 'https://api.epsonconnect.com'
         self.access_token = None
         self.subject_id = None
         self.job_id = None
@@ -30,65 +30,65 @@ class PysonConnect:
         
     
     def authentification(self, username):
-        req_uri = f"{self.base_uri}/api/1/printing/oauth2/auth/token?subject=printer"
+        req_uri = f'{self.base_uri}/api/1/printing/oauth2/auth/token?subject=printer'
         headers = {
-                "Content-Type":"application/x-www-form-urlencoded"
+                'Content-Type':'application/x-www-form-urlencoded'
                 }
         data = {
-                "grant_type":"password",
-                "username":username,
-                "password":""
+                'grant_type':'password',
+                'username':username,
+                'password':''
                 }
 
         r = requests.post(url=req_uri, headers=headers, data=data, auth=HTTPBasicAuth(self.client_id, self.client_secret))
         rjson = r.json()
 
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
             
         else:
-            self.access_token = rjson["access_token"]
-            expires_in = rjson["expires_in"]
-            refresh_token = rjson["refresh_token"]
-            self.subject_id = rjson["subject_id"]
+            self.access_token = rjson['access_token']
+            expires_in = rjson['expires_in']
+            refresh_token = rjson['refresh_token']
+            self.subject_id = rjson['subject_id']
 
             return_data = {
-                    "access_token":self.access_token,
-                    "expires_in":expires_in,
-                    "refresh_token":refresh_token,
-                    "subject_id":self.subject_id
+                    'access_token':self.access_token,
+                    'expires_in':expires_in,
+                    'refresh_token':refresh_token,
+                    'subject_id':self.subject_id
                     }
             return return_data
 
 
     def reissue_access_token(self, refresh_token):
-        req_uri = f"{self.base_uri}/api/1/printing/oauth2/auth/token?subject=printer"
+        req_uri = f'{self.base_uri}/api/1/printing/oauth2/auth/token?subject=printer'
         headers = {
-                "Content-Type":"application/x-www-form-urlencoded"
+                'Content-Type':'application/x-www-form-urlencoded'
                 }
         data = {
-                "grant_type":"refresh_token",
-                "refresh_token":refresh_token
+                'grant_type':'refresh_token',
+                'refresh_token':refresh_token
                 }
         r = requests.post(url=req_uri, headers=headers, data=data, auth=HTTPBasicAuth(self.client_id, self.client_secret))
         rjson = r.json()
 
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
             
         else:
-            self.access_token = rjson["access_token"]
-            expires_in = rjson["expires_in"]
-            self.subject_id = rjson["subject_id"]
+            self.access_token = rjson['access_token']
+            expires_in = rjson['expires_in']
+            self.subject_id = rjson['subject_id']
 
             return_data = {
-                    "access_token":self.access_token,
-                    "expires_in":expires_in,
-                    "subject_id":self.subject_id
+                    'access_token':self.access_token,
+                    'expires_in':expires_in,
+                    'subject_id':self.subject_id
                     }
             return return_data
 
@@ -100,14 +100,14 @@ class PysonConnect:
         if not subject_id:
             subject_id = self.subject_id
 
-        req_uri = f"{self.base_uri}/api/1/printing/printers/{subject_id}/capability/{document_type}"
+        req_uri = f'{self.base_uri}/api/1/printing/printers/{subject_id}/capability/{document_type}'
         headers = {
-                "Authorization":f"Bearer {access_token}"
+                'Authorization':f'Bearer {access_token}'
                 }
         r = requests.get(url=req_uri, headers=headers)
 
         rjson = r.json()
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
@@ -123,40 +123,40 @@ class PysonConnect:
         if not subject_id:
             subject_id = self.subject_id
 
-        req_uri = f"{self.base_uri}/api/1/printing/printers/{subject_id}/jobs"
+        req_uri = f'{self.base_uri}/api/1/printing/printers/{subject_id}/jobs'
         headers = {
-                "Authorization":f"Bearer {access_token}",
-                "Content-Type":f"application/json"
+                'Authorization':f'Bearer {access_token}',
+                'Content-Type':f'application/json'
                 }
         r = requests.post(url=req_uri, headers=headers, data=json.dumps(setting_data))
         rjson = r.json()
 
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
             
         else:
-            self.job_id = rjson["id"]
-            self.upload_uri = rjson["upload_uri"]
+            self.job_id = rjson['id']
+            self.upload_uri = rjson['upload_uri']
 
             return_data = {
-                    "job_id":self.job_id,
-                    "upload_uri":self.upload_uri
+                    'job_id':self.job_id,
+                    'upload_uri':self.upload_uri
                     }
             return return_data
             
 
     def upload_print_file(self, file_path, document_type, job_id=None, upload_uri=None):
-        l_ext = [".jpg", ".JPG", ".jpeg", ".JPEG", ".png", ".PNG", ".tiff", ".TIFF"]
+        l_ext = ['.jpg', '.JPG', '.jpeg', '.JPEG', '.png', '.PNG', '.tiff', '.TIFF']
         dl_data = None
 
-        if "http" in file_path:
-            lf_path = file_path.split(".")
+        if 'http' in file_path:
+            lf_path = file_path.split('.')
             tmp_name = lf_path[-2]
-            name = tmp_name.split("/")[-1]
+            name = tmp_name.split('/')[-1]
             extension = lf_path[-1]
-            dl_data = f"{name}.{extension}"
+            dl_data = f'{name}.{extension}'
             r = requests.get(file_path)
             status_code = r.status_code
             if status_code != 200:
@@ -164,7 +164,7 @@ class PysonConnect:
             
             else:
                 data = r.content
-                with open(dl_data, "wb") as f:
+                with open(dl_data, 'wb') as f:
                     f.write(data)
 
                 file_path = dl_data
@@ -179,27 +179,27 @@ class PysonConnect:
 
             del_exif = Image.new(mode, size)
             del_exif.putdata(imgData)
-            del_exif.save(f"del_{name}{extension}")
+            del_exif.save(f'del_{name}{extension}')
 
-            file_path = f"del_{name}{extension}"
+            file_path = f'del_{name}{extension}'
 
-        with open(file_path, "rb") as f:
+        with open(file_path, 'rb') as f:
             data = f.read()
             
         date_size = os.path.getsize(file_path)
-        if document_type == "document" and date_size < 200000000:
-            content_type = "application/octet-stream"
+        if document_type == 'document' and date_size < 200000000:
+            content_type = 'application/octet-stream'
             
-        elif document_type == "photo" and date_size < 100000000:
-            content_type = "image/jpeg"
+        elif document_type == 'photo' and date_size < 100000000:
+            content_type = 'image/jpeg'
 
         else:
             self.err.errors()
 
-        req_uri = f"{self.upload_uri}&File=1{extension}"
+        req_uri = f'{self.upload_uri}&File=1{extension}'
         headers = {
-                "Content-Length":str(date_size),
-                "Content-Type":content_type
+                'Content-Length':str(date_size),
+                'Content-Type':content_type
                 }
         r = requests.post(url=req_uri, headers=headers, data=data)
         status_code = r.status_code
@@ -211,7 +211,7 @@ class PysonConnect:
             if dl_data:
                 os.remove(dl_data)
 
-            if "del_" in file_path:
+            if 'del_' in file_path:
                 os.remove(file_path)
 
 
@@ -225,33 +225,33 @@ class PysonConnect:
         if job_id == None:
             job_id = self.job_id
 
-        req_uri = f"{self.base_uri}/api/1/printing/printers/{subject_id}/jobs/{job_id}/print"
+        req_uri = f'{self.base_uri}/api/1/printing/printers/{subject_id}/jobs/{job_id}/print'
         headers = {
-                "Authorization":f"Bearer {access_token}",
-                "Content-Type":"application/json"
+                'Authorization':f'Bearer {access_token}',
+                'Content-Type':'application/json'
                 }
         r = requests.post(url=req_uri, headers=headers)
         rjson = r.json()
 
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
 
 
-    def cancel_print(self, access_token, subject_id, job_id, opBy="user"):
-        req_uri = f"{self.base_uri}/api/1/printing/printers/{subject_id}/jobs/{job_id}/cancel"
+    def cancel_print(self, access_token, subject_id, job_id, opBy='user'):
+        req_uri = f'{self.base_uri}/api/1/printing/printers/{subject_id}/jobs/{job_id}/cancel'
         headers = {
-                "Authorization":f"Bearer {access_token}",
-                "Content-Type":"application/json"
+                'Authorization':f'Bearer {access_token}',
+                'Content-Type':'application/json'
                 }
         data = {
-                "operated_by":opBy
+                'operated_by':opBy
                 }
         r = requests.post(url=req_uri, headers=headers, data=json.dumps(data))
         rjson = r.json()
 
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
@@ -267,33 +267,33 @@ class PysonConnect:
         if job_id == None:
             job_id = self.job_id
 
-        req_uri = f"{self.base_uri}/api/1/printing/printers/{subject_id}/jobs/{job_id}"
+        req_uri = f'{self.base_uri}/api/1/printing/printers/{subject_id}/jobs/{job_id}'
         headers = {
-                "Authorization":f"Bearer {access_token}"
+                'Authorization':f'Bearer {access_token}'
                 }
         r = requests.get(url=req_uri, headers=headers)
         rjson = r.json()
 
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
 
         else:            
-            status = rjson["status"]
-            status_reason = rjson["status_reason"]
-            start_date = rjson["start_date"]
-            job_name = rjson["job_name"]
-            ttl_pages = rjson["total_pages"]
-            update_date = rjson["update_date"]
+            status = rjson['status']
+            status_reason = rjson['status_reason']
+            start_date = rjson['start_date']
+            job_name = rjson['job_name']
+            ttl_pages = rjson['total_pages']
+            update_date = rjson['update_date']
 
             return_data = {
-                    "status":status,
-                    "status_reason":status_reason,
-                    "start_date":start_date,
-                    "job_name":job_name,
-                    "ttl_pages":ttl_pages,
-                    "update_date":update_date
+                    'status':status,
+                    'status_reason':status_reason,
+                    'start_date':start_date,
+                    'job_name':job_name,
+                    'ttl_pages':ttl_pages,
+                    'update_date':update_date
                     }
             return return_data
 
@@ -305,40 +305,40 @@ class PysonConnect:
         if subject_id == None:
             subject_id = self.subject_id
 
-        req_uri = f"{self.base_uri}/api/1/printing/printers/{subject_id}"
+        req_uri = f'{self.base_uri}/api/1/printing/printers/{subject_id}'
         headers = {
-                "Authorization":f"Bearer {access_token}"
+                'Authorization':f'Bearer {access_token}'
                 }
         r = requests.get(url=req_uri, headers=headers)
         rjson = r.json()
 
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
             
         else:
-            printer_name = rjson["printer_name"]
-            serial_no = rjson["serial_no"]
-            ec_connected = rjson["ec_connected"]
+            printer_name = rjson['printer_name']
+            serial_no = rjson['serial_no']
+            ec_connected = rjson['ec_connected']
 
             return_data = {
-                    "printer_name":printer_name,
-                    "serial_no":serial_no,
-                    "ec_connected":ec_connected
+                    'printer_name':printer_name,
+                    'serial_no':serial_no,
+                    'ec_connected':ec_connected
                     }
             return return_data
 
 
     def cancel_authentication(self, access_token, subject_id):
-        req_uri = f"{self.base_uri}/api/1/printing/printers/{subject_id}"
+        req_uri = f'{self.base_uri}/api/1/printing/printers/{subject_id}'
         headers = {
-                "Authorization":f"Bearer {access_token}" 
+                'Authorization':f'Bearer {access_token}' 
                 }
         r = requests.delete(url=req_uri, headers=headers)
         rjson = r.json()
 
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
@@ -351,15 +351,15 @@ class PysonConnect:
         if subject_id == None:
             subject_id = self.subject_id 
 
-        req_uri = f"{self.base_uri}/api/1/printing/printers/{subject_id}/settings/notification"
+        req_uri = f'{self.base_uri}/api/1/printing/printers/{subject_id}/settings/notification'
         headers = {
-                "Authorization":f"Bearer {access_token}",
-                "Content-Type":"application/json"
+                'Authorization':f'Bearer {access_token}',
+                'Content-Type':'application/json'
                 }
         r = requests.post(url=req_uri, headers=headers, data=json.dumps(data))
         rjson = r.json()
 
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
@@ -372,32 +372,32 @@ class PysonConnect:
         if subject_id == None:
             subject_id = self.subject_id 
 
-        req_uri = f"{self.base_uri}/api/1/scanning/scanners/{subject_id}/destinations"
+        req_uri = f'{self.base_uri}/api/1/scanning/scanners/{subject_id}/destinations'
         headers = {
-                "Authorization":f"Bearer {access_token}"
+                'Authorization':f'Bearer {access_token}'
                 }
         r = requests.get(url=req_uri, headers=headers)
         rjson = r.json()
 
         dests = []
         dest_data = {}
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
             
         else:
-            destinations = rjson["destinations"]
+            destinations = rjson['destinations']
             for dest in destinations:
-                dest_data["scan_dest_id"] = dest["id"]
-                dest_data["alias_name"] = dest["alias_name"]
-                dest_data["dest_type"] = dest["type"]
-                dest_data["destination"] = dest["destination"]
+                dest_data['scan_dest_id'] = dest['id']
+                dest_data['alias_name'] = dest['alias_name']
+                dest_data['dest_type'] = dest['type']
+                dest_data['destination'] = dest['destination']
                 dests.append(dest_data)
                 dest_data = {}
 
             return_data = {
-                    "destinations":dests
+                    'destinations':dests
                     }
             return return_data
 
@@ -409,20 +409,20 @@ class PysonConnect:
         if subject_id == None:
             subject_id = self.subject_id
 
-        req_uri = f"{self.base_uri}/api/1/scanning/scanners/{subject_id}/destinations"
+        req_uri = f'{self.base_uri}/api/1/scanning/scanners/{subject_id}/destinations'
         headers = {
-                "Authorization":f"Bearer {access_token}",
-                "Content-Type":"application/json"
+                'Authorization':f'Bearer {access_token}',
+                'Content-Type':'application/json'
                 }
         data = {
-                "alias_name":data["alias_name"],
-                "type":data["dest_type"],
-                "destination":data["destination"]
+                'alias_name':data['alias_name'],
+                'type':data['dest_type'],
+                'destination':data['destination']
                 }
         r = requests.post(url=req_uri, headers=headers, data=json.dumps(data))
         rjson = r.json()
 
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
@@ -435,39 +435,39 @@ class PysonConnect:
         if subject_id == None:
             subject_id = self.subject_id
 
-        req_uri = f"{self.base_uri}/api/1/scanning/scanners/{subject_id}/destinations"
+        req_uri = f'{self.base_uri}/api/1/scanning/scanners/{subject_id}/destinations'
         headers = {
-                "Authorization":f"Bearer {access_token}",
-                "Content-Type":"application/json"
+                'Authorization':f'Bearer {access_token}',
+                'Content-Type':'application/json'
                 }
         data = {
-                "id":data["scan_dest_id"],
-                "alias_name":data["alias_name"],
-                "type":data["dest_type"],
-                "destination":data["destination"]
+                'id':data['scan_dest_id'],
+                'alias_name':data['alias_name'],
+                'type':data['dest_type'],
+                'destination':data['destination']
                 }
         r = requests.put(url=req_uri, headers=headers, data=json.dumps(data))
         rjson = r.json()
 
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
 
     
     def delete_scan_destination(self, access_token, subject_id, scan_dest_id):
-        req_uri = f"{self.base_uri}/api/1/scanning/scanners/{subject_id}/destinations"
+        req_uri = f'{self.base_uri}/api/1/scanning/scanners/{subject_id}/destinations'
         headers = {
-                "Authorization":f"Bearer {access_token}",
-                "Content-Type":"application/json"
+                'Authorization':f'Bearer {access_token}',
+                'Content-Type':'application/json'
                 }
         data = {
-                "id":scan_dest_id
+                'id':scan_dest_id
                 }
         r = requests.delete(url=req_uri, headers=headers, data=json.dumps(data))
         rjson = r.json()
 
-        if "error" in rjson or "code" in rjson:
+        if 'error' in rjson or 'code' in rjson:
             key = list(rjson.keys())[0]
             message = rjson[key]
             self.err.errors(message=message)
